==> qtjambi-help-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiHelp/QHelpContentWidget_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtHelp/qhelpcontentwidget.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qwindow.h>
#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#if QT_CONFIG(itemviews)
#include <QtWidgets/qheaderview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpContentWidget_0(){
    static int result = QMetaMethod::fromSignal(&QHelpContentWidget::linkActivated).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpContentWidget::indexOf(QUrl)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentWidget_indexOf_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID link0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpContentWidget *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentWidget>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentWidget::indexOf(QUrl)", __qt_this)
        const QUrl& __qt_link0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(link0);
        QModelIndex __qt_return_value = __qt_this->indexOf(__qt_link0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QUrl*>(out) = qtjambi_cast<const QUrl& >(env, in.l);
    }else{
        out = const_cast<QUrl*>(&qtjambi_cast<const QUrl& >(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QUrl const*>(in));
    return true;
}


void initialize_meta_info_QHelpContentWidget(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpContentWidget>("QHelpContentWidget", "io/qt/help/QHelpContentWidget");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpContentWidget::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "linkActivated", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QHelpContentWidget_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpContentWidget_0()){ // linkActivated(const QUrl & link)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QPaintDevice), int(reinterpret_cast<quintptr>(static_cast<QPaintDevice *>(reinterpret_cast<QHelpContentWidget *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHelp/QHelpContentWidget_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtHelp/qhelpcontentwidget.h>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qurl.h>
#include <QtGui/qregion.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qitemselectionmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtGui/qevent.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qheaderview.h>
#endif //QT_CONFIG(itemviews)
#include <QtCore/qnamespace.h>
#include <QtCore/qrect.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/qsize.h>
#include <QtCore/QList>
#include <QtCore/qpoint.h>
#include <QtCore/qobject.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qwidget.h>
#include <QtWidgets/qabstractscrollarea.h>
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtCore/qmargins.h>
#include <QtWidgets/qframe.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qcursor.h>
#include <QtGui/qicon.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qlocale.h>
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtGui/qwindow.h>
#include <QtGui/qpalette.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qscreen.h>
#include <QtWidgets/qlayout.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qpixmap.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qfont.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qbitmap.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtCore/qtimer.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qthread.h>
#include <QtCore/qmetaobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QHelpContentWidget_0(){
    static int result = QMetaMethod::fromSignal(&QHelpContentWidget::linkActivated).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpContentWidget::indexOf(QUrl)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpContentWidget_indexOf_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID link0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QHelpContentWidget *__qt_this = QtJambiAPI::objectFromNativeId<QHelpContentWidget>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QHelpContentWidget::indexOf(QUrl)", __qt_this)
        const QUrl& __qt_link0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(link0);
        QModelIndex __qt_return_value = __qt_this->indexOf(__qt_link0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QUrl_cref(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool nativeToJavaConverter_QUrl_cref(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    if(out){
        *reinterpret_cast<QUrl*>(out) = qtjambi_cast<const QUrl& >(env, in.l);
    }else{
        out = const_cast<QUrl*>(&qtjambi_cast<const QUrl& >(env, in.l));
    }
    return true;
}

bool nativeToJavaConverter_QUrl_cref(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QUrl const*>(in));
    return true;
}


void initialize_meta_info_QHelpContentWidget(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QHelpContentWidget>("QHelpContentWidget", "io/qt/help/QHelpContentWidget");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QHelpContentWidget::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "linkActivated", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QHelpContentWidget_0)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QHelpContentWidget_0()){ // linkActivated(const QUrl & link)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // const QUrl&
                                method.parameterType(0),
                                "io/qt/core/QUrl",
                                &nativeToJavaConverter_QUrl_cref,
                                &javaToNativeConverter_QUrl_cref);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QPaintDevice), int(reinterpret_cast<quintptr>(static_cast<QPaintDevice *>(reinterpret_cast<QHelpContentWidget *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
